"""Shot management."""

import attr
import flask_login

import pillarsdk
from pillar.web.system_util import pillar_api

from . import attrs_extra
from .node_types.shot import node_type_shot


@attr.s
class ShotManager(object):
    _log = attrs_extra.log('%s.ShotManager' % __name__)

    def create_shot(self, project):
        """Creates a new shot, owned by the current user.

        :rtype: pillarsdk.Node
        """

        api = pillar_api()
        node_type = project.get_node_type(node_type_shot['name'])
        if not node_type:
            raise ValueError('Project %s not set up for Attract' % project._id)

        node_props = dict(
            name='New shot',
            project=project['_id'],
            user=flask_login.current_user.objectid,
            node_type=node_type['name'],
            properties={
                'status': node_type['dyn_schema']['status']['default'],
            },
        )

        shot = pillarsdk.Node(node_props)
        shot.create(api=api)
        return shot
